@@ -33,12 +33,13 @@ and will then receive a return value or exception as appropriate.
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 1
+__ver_patch__ = 2
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
 
 import wx
+import sys
 import threading
 
 _EVT_INVOKE_METHOD = wx.NewId()
@@ -47,12 +48,12 @@ class MethodInvocationEvent(wx.PyEvent):
     """Event fired to the GUI thread indicating a method invocation."""
 
     def __init__(self,func,args,kwds):
-      wx.PyEvent.__init__(self)
-      self.SetEventType(_EVT_INVOKE_METHOD)
-      self.func = func
-      self.args = args
-      self.kwds = kwds
-      self.event = threading.Event()
+        wx.PyEvent.__init__(self)
+        self.SetEventType(_EVT_INVOKE_METHOD)
+        self.func = func
+        self.args = args
+        self.kwds = kwds
+        self.event = threading.Event()
 
     def invoke(self):
         """Invoke the method, blocking until the main thread handles it."""
@@ -61,20 +62,24 @@ class MethodInvocationEvent(wx.PyEvent):
         try:
             return self.result
         except AttributeError:
-            raise self.exception
+            tb = self.traceback
+            del self.traceback
+            raise type(self.exception), self.exception, tb
 
     def process(self):
         """Execute the method and signal that it is ready."""
         try:
             self.result = self.func(*self.args,**self.kwds)
         except Exception, e:
-            self.exception = e
+            _,self.exception,self.traceback = sys.exc_info()
         self.event.set()
 
+
 def handler(evt):
     """Simple event handler to register for invocation events."""
     evt.process()
 
+
 def anythread(func):
     """Method decorator allowing call from any thread.
 
@@ -86,15 +91,15 @@ def anythread(func):
     When invoked from the main thread, the function is executed immediately.
     """
     def invoker(*args,**kwds):
-      if wx.Thread_IsMain():
-        return func(*args,**kwds)
-      else:
-        self = args[0]
-        if not hasattr(self,"_AnyThread__connected"):
-          self.Connect(-1,-1,_EVT_INVOKE_METHOD,handler)
-          self._AnyThread__connected = True
-        evt = MethodInvocationEvent(func,args,kwds)
-        return evt.invoke()
+        if wx.Thread_IsMain():
+            return func(*args,**kwds)
+        else:
+            self = args[0]
+            if not hasattr(self,"_AnyThread__connected"):
+                self.Connect(-1,-1,_EVT_INVOKE_METHOD,handler)
+                self._AnyThread__connected = True
+            evt = MethodInvocationEvent(func,args,kwds)
+            return evt.invoke()
     invoker.__name__ = func.__name__
     invoker.__doc__ = func.__doc__
     return invoker
